@@ -26,7 +26,7 @@ var gAdvancedPane = {
     // Search integration -- check whether we should hide or disable integration
     let hideSearchUI = false;
     let disableSearchUI = false;
-    Components.utils.import("resource://app/modules/SearchIntegration.js");
+    Components.utils.import("resource:///modules/SearchIntegration.js");
     if (SearchIntegration)
     {
       if (SearchIntegration.osVersionTooLow)
@@ -196,12 +196,14 @@ var gAdvancedPane = {
   {
     var aus = 
         Components.classes["@mozilla.org/updates/update-service;1"].
-        getService(Components.interfaces.nsIApplicationUpdateService);
+//@line 236 "/home/karma/src/build/mail/components/preferences/advanced.js"
+        getService(Components.interfaces.nsIApplicationUpdateService2);
+//@line 240 "/home/karma/src/build/mail/components/preferences/advanced.js"
 
     var enabledPref = document.getElementById("app.update.enabled");
     var enableAppUpdate = document.getElementById("enableAppUpdate");
 
-    enableAppUpdate.disabled = !aus.canUpdate || enabledPref.locked;
+    enableAppUpdate.disabled = !aus.canCheckForUpdates || enabledPref.locked;
   },
 
   updateAutoItems: function () 
@@ -261,7 +263,7 @@ var gAdvancedPane = {
                              .createInstance(Components.interfaces.nsIUpdatePrompt);
     prompter.showUpdateHistory(window);
   },
-//@line 301 "/home/karma/src/build/mail/components/preferences/advanced.js"
+//@line 305 "/home/karma/src/build/mail/components/preferences/advanced.js"
 
   /**
    * The Extensions checkbox and button are disabled only if the enable Addon
