@@ -1,4 +1,4 @@
-/* -*- Mode: Java; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
+/* -*- Mode: JavaScript; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /* ***** BEGIN LICENSE BLOCK *****
  * Version: MPL 1.1/GPL 2.0/LGPL 2.1
  *
@@ -20,6 +20,7 @@
  * the Initial Developer. All Rights Reserved.
  *
  * Contributor(s):
+ *   Joachim Herb <herb@leo.org>
  *
  * Alternatively, the contents of this file may be used under the terms of
  * either the GNU General Public License Version 2 or later (the "GPL"), or
@@ -35,30 +36,30 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-//@line 39 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
+//@line 40 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
 
-//@line 45 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
+//@line 46 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
 
-pref("general.useragent.extra.thunderbird", "Shredder/3.0.11");
+pref("general.useragent.extra.thunderbird", "Lanikai/3.1.8");
 
 pref("general.useragent.locale", "ja");
 pref("general.skins.selectedSkin", "classic/1.0");
 
-//@line 55 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
+//@line 56 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
 
 pref("mail.rights.version", 0);
 
 // Don't show the about:rights notification in debug or non-official builds.
-//@line 63 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
+//@line 64 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
 pref("mail.rights.override", true);
-//@line 65 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
+//@line 66 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
 
 // gtk2 (*nix) lacks transparent/translucent drag support (bug 376238), so we
 // want to disable it so people can see where they are dragging things.
 // (Stock gtk drag icons will be used instead.)
-//@line 70 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
+//@line 71 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
 pref("nglayout.enable_drag_images", false);
-//@line 72 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
+//@line 73 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
 
 // App-specific update preferences
 
@@ -95,9 +96,6 @@ pref("app.update.url.details", "http://www.mozillamessaging.com/%LOCALE%/%APP%/r
 // User-settable override to app.update.url for testing purposes.
 //pref("app.update.url.override", "");
 
-// Interval: Time between checks for a new version (in seconds)
-//           default=1 day
-pref("app.update.interval", 86400);
 // Interval: Time before prompting the user again to restart to install the
 //           latest download (in seconds) default=1 day
 pref("app.update.nagTimer.restart", 86400);
@@ -125,8 +123,8 @@ pref("app.support.baseURL", "http://support.live.mozillamessaging.com/%LOCALE%/%
 // Blocklist preferences
 pref("extensions.blocklist.enabled", true);
 pref("extensions.blocklist.interval", 86400);
-pref("extensions.blocklist.url", "https://addons.mozilla.org/blocklist/2/%APP_ID%/%APP_VERSION%/%PRODUCT%/%BUILD_ID%/%BUILD_TARGET%/%LOCALE%/%CHANNEL%/%OS_VERSION%/%DISTRIBUTION%/%DISTRIBUTION_VERSION%/");
-pref("extensions.blocklist.detailsURL", "http://%LOCALE%.www.mozilla.com/%LOCALE%/blocklist/");
+pref("extensions.blocklist.url", "https://addons.mozilla.org/blocklist/3/%APP_ID%/%APP_VERSION%/%PRODUCT%/%BUILD_ID%/%BUILD_TARGET%/%LOCALE%/%CHANNEL%/%OS_VERSION%/%DISTRIBUTION%/%DISTRIBUTION_VERSION%/");
+pref("extensions.blocklist.detailsURL", "https://www.mozilla.com/%LOCALE%/blocklist/");
 
 // Developers can set this to |true| if they are constantly changing files in their
 // extensions directory so that the extension system does not constantly think that
@@ -143,7 +141,7 @@ pref("extensions.logging.enabled", false);
 //  .. etc ..
 //
 pref("extensions.update.enabled", true);
-pref("extensions.update.url", "https://versioncheck.addons.mozilla.org/update/VersionCheck.php?reqVersion=%REQ_VERSION%&id=%ITEM_ID%&version=%ITEM_VERSION%&maxAppVersion=%ITEM_MAXAPPVERSION%&status=%ITEM_STATUS%&appID=%APP_ID%&appVersion=%APP_VERSION%&appOS=%APP_OS%&appABI=%APP_ABI%&locale=%APP_LOCALE%&currentAppVersion=%CURRENT_APP_VERSION%");
+pref("extensions.update.url", "https://versioncheck.addons.mozilla.org/update/VersionCheck.php?reqVersion=%REQ_VERSION%&id=%ITEM_ID%&version=%ITEM_VERSION%&maxAppVersion=%ITEM_MAXAPPVERSION%&status=%ITEM_STATUS%&appID=%APP_ID%&appVersion=%APP_VERSION%&appOS=%APP_OS%&appABI=%APP_ABI%&locale=%APP_LOCALE%&currentAppVersion=%CURRENT_APP_VERSION%&updateType=%UPDATE_TYPE%");
 
 pref("extensions.update.interval", 86400);  // Check for updates to Extensions and 
                                             // Themes every day
@@ -159,15 +157,15 @@ pref("extensions.{972ce4c6-7e08-4474-a285-3208198ce6fd}.description", "chrome://
 
 // Preferences for the Get Add-ons pane
 pref("extensions.getAddons.showPane", true);
-pref("extensions.getAddons.browseAddons", "https://%LOCALE%.add-ons.mozilla.com/%LOCALE%/%APP%");
+pref("extensions.getAddons.browseAddons", "https://addons.mozilla.org/%LOCALE%/%APP%");
 pref("extensions.getAddons.maxResults", 5);
-pref("extensions.getAddons.recommended.browseURL", "https://%LOCALE%.add-ons.mozilla.com/%LOCALE%/%APP%/recommended");
+pref("extensions.getAddons.recommended.browseURL", "https://addons.mozilla.org/%LOCALE%/%APP%/recommended");
 pref("extensions.getAddons.recommended.url", "https://services.addons.mozilla.org/%LOCALE%/%APP%/api/%API_VERSION%/list/featured/all/10/%OS%/%VERSION%");
-pref("extensions.getAddons.search.browseURL", "https://%LOCALE%.add-ons.mozilla.com/%LOCALE%/%APP%/search?q=%TERMS%");
+pref("extensions.getAddons.search.browseURL", "https://addons.mozilla.org/%LOCALE%/%APP%/search?q=%TERMS%");
 pref("extensions.getAddons.search.url", "https://services.addons.mozilla.org/%LOCALE%/%APP%/api/%API_VERSION%/search/%TERMS%/all/10/%OS%/%VERSION%");
 
-pref("xpinstall.whitelist.add", "update.mozilla.org");
-pref("xpinstall.whitelist.add.103", "addons.mozilla.org");
+pref("xpinstall.whitelist.add", "addons.mozilla.org");
+pref("xpinstall.whitelist.add.36", "getpersonas.com");
 
 pref("mail.shell.checkDefaultClient", true);
 pref("mail.spellcheck.inline", true);
@@ -184,11 +182,11 @@ pref("mail.last_msg_movecopy_target_uri", "");
 // last move or copy operation was a move
 pref("mail.last_msg_movecopy_was_move", true);
 
-//@line 200 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
+//@line 198 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
 pref("browser.preferences.instantApply", true);
-//@line 205 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
+//@line 203 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
 pref("browser.preferences.animateFadeIn", false);
-//@line 207 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
+//@line 205 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
 
 pref("browser.download.show_plugins_in_list", false);
 pref("browser.download.hide_plugins_without_extensions", true);
@@ -200,6 +198,13 @@ pref("accessibility.typeaheadfind.flashBar", 1);
 
 pref("mail.close_message_window.on_delete", false);
 
+// Number of lines of To/CC/BCC address headers to show before "more"
+// truncates the list.
+pref("mailnews.headers.show_n_lines_before_more", 1);
+
+// Thunderbird wants to show the migration assistant on upgrade by default.
+pref("mail.ui.show.migration.on.upgrade", true);
+
 /////////////////////////////////////////////////////////////////
 // Overrides of the core mailnews.js prefs
 /////////////////////////////////////////////////////////////////
@@ -219,9 +224,6 @@ pref("mailnews.headers.minNumHeaders", 0); // 0 means we ignore this pref
 // 3="<author> wrote On <date>:", 4=user specified
 pref("mailnews.reply_header_type", 2);
 
-// This turns off always showing a reply button in the message reader header
-pref("mailnews.headers.always_show_reply_sender", true);
-
 pref("mail.operate_on_msgs_in_collapsed_threads", true);
 pref("mail.warn_on_collapsed_thread_operation", true);
 
@@ -260,9 +262,9 @@ pref("offline.send.unsent_messages",            0);
 // 2 Never synchronize the offline store when going offline
 pref("offline.download.download_messages",  0);
 
-//@line 279 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
+//@line 281 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
 pref("offline.autoDetect", false);
-//@line 285 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
+//@line 287 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
 
 // Expose only select protocol handlers. All others should go
 // through the external protocol handler route.
@@ -342,7 +344,7 @@ pref("mail.directory",                  "");
 pref("news.directory",                  "");
 pref("spellchecker.dictionary", "");
 // Dictionary download preference
-pref("spellchecker.dictionaries.download.url", "https://%LOCALE%.add-ons.mozilla.com/%LOCALE%/%APP%/%VERSION%/dictionaries/");
+pref("spellchecker.dictionaries.download.url", "https://addons.mozilla.org/%LOCALE%/%APP%/dictionaries/");
 
 // profile.force.migration can be used to bypass the migration wizard, forcing migration from a particular
 // mail application without any user intervention. Possible values are: 
@@ -378,7 +380,8 @@ pref("browser.safebrowsing.provider.0.reportErrorURL", "http://{moz:locale}.phis
 pref("browser.safebrowsing.provider.0.reportPhishURL", "http://{moz:locale}.phish-report.mozilla.com/?hl={moz:locale}");
 
 // FAQ URL
-pref("browser.safebrowsing.warning.infoURL", "http://%LOCALE%.www.mozilla.com/%LOCALE%/firefox/phishing-protection/");
+// XXX Firefox is hard-coded because we haven't got our own version yet.
+pref("browser.safebrowsing.warning.infoURL", "http://www.mozilla.com/%LOCALE%/firefox/phishing-protection/");
 
 // prevent status-bar spoofing even if people are foolish enough to turn on JS
 pref("dom.disable_window_status_change",          true);
@@ -415,27 +418,32 @@ pref("mail.tabs.closeButtons", 1);
 pref("breakpad.reportURL", "http://crash-stats.mozilla.com/report/index/");
 
 // OS Integrated Search and Indexing
-//@line 446 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
+//@line 449 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
 
 // -- Windows Search/Spotlight logging options
-//@line 461 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
+//@line 464 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
 
 // Whether to use a panel that looks like an OS X sheet for customization
-//@line 466 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
+//@line 469 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
 pref("toolbar.customization.usesheet", false);
-//@line 468 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
+//@line 471 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
 
 // Check for missing attachments?
 pref("mail.compose.attachment_reminder", true);
 // Words that should trigger a missing attachments warning.
 pref("mail.compose.attachment_reminder_keywords", "chrome://messenger/locale/messengercompose/composeMsgs.properties");
+// When no action is taken on the inline missing attachement notification,
+// show an alert on send?
+pref("mail.compose.attachment_reminder_aggressive", true);
 
 pref("browser.formfill.enable", true);
+//@line 482 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
 // Override the all.js values so that unit tests pass and we get sane values.
 pref("browser.formfill.expire_days", 180);
 pref("browser.history_expire_days", 180);
 pref("browser.history_expire_days_min", 90);
 pref("browser.history_expire_sites", 40000);
+//@line 488 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
 
 // Disable autoplay as we don't handle audio elements in emails very well.
 // See bug 515082.
@@ -452,6 +460,35 @@ pref("mailnews.database.global.logging.console", true);
 // page to load to find good header add-ons
 pref("mailnews.migration.header_addons_url","http://live.mozillamessaging.com/%APP%/addons/search?q=header&locale=%LOCALE%&lver=%VERSION%&hver=%VERSION%&os=%OS%");
 
+// Serif fonts look dated.  Switching those language families to sans-serif
+// where we think it makes sense.  Worth investigating for other font families
+// as well, viz bug 520824.  See all.js for the rest of the font families
+// preferences.
+pref("font.default", "sans-serif");
+pref("font.default.x-unicode", "sans-serif");
+pref("font.default.x-western", "sans-serif");
+
+//@line 527 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
+
+// Since different versions of Windows need different settings, we'll handle
+// this in mailMigrator.js.
+
+// Linux, in other words.  Other OSes may wish to override.
+//@line 533 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
+// The font.name-list fallback is defined in case font.name isn't
+// present -- e.g. in case a profile that's been used on Windows Vista or above
+// is used on Linux.
+pref("font.name-list.serif.x-unicode", "serif");
+pref("font.name-list.sans-serif.x-unicode", "sans-serif");
+pref("font.name-list.monospace.x-unicode", "monospace");
+
+pref("font.name-list.serif.x-western", "serif");
+pref("font.name-list.sans-serif.x-western", "sans-serif");
+pref("font.name-list.monospace.x-western", "monospace");
+//@line 544 "/home/karma/src/build/mail/app/profile/all-thunderbird.js"
+
+pref("mail.font.windows.version", 0);
+
 // What level of warning should we send to the error console?
 pref("mail.wizard.logging.console", "None");
 // What level of warning should we send to stdout via dump?
@@ -476,3 +513,7 @@ pref("browser.link.open_newwindow", 3);
 pref("browser.link.open_newwindow.restriction", 0);
 
 pref("browser.tabs.loadDivertedInBackground", false);
+
+// Plugins are disabled due to a performance regression when they're on. See bug
+// 599119.
+pref("plugin.disable", true);
